@@ -170,7 +170,7 @@ class Analysis_controller:
         return ds.relax_gui.analyses[self._current].analysis_type
 
 
-    def delete_all(self):
+    def delete_all(self, reset=False):
         """Remove all analyses."""
 
         # Debugging set up.
@@ -196,7 +196,7 @@ class Analysis_controller:
             # Remove the last analysis, until there is nothing left.
             if status.debug:
                 print("debug> %s:  Deleting the analysis at index %s." % (full_name, self._num_analyses-1))
-            self.delete_analysis(self._num_analyses-1)
+            self.delete_analysis(self._num_analyses-1, reset=reset)
 
         # Notify the observers of the change.
         if status.debug:
@@ -204,7 +204,7 @@ class Analysis_controller:
         status.observers.gui_analysis.notify()
 
 
-    def delete_analysis(self, index):
+    def delete_analysis(self, index, reset=False):
         """Delete the analysis tab and data store corresponding to the index.
 
         The order of these operations is very important due to the notification of observer objects and the updates, synchronisations, etc. that follow.  If the program debugging mode is on, then printouts at each stage will occur to allow the following of the code and observer object notifications.
@@ -237,6 +237,7 @@ class Analysis_controller:
             if status.debug:
                 print("debug> %s:  Executing the analysis specific delete() method." % full_name)
             self._analyses[index].delete()
+        wx.Yield()
 
         # Delete the tab.
         if status.debug:
@@ -248,20 +249,22 @@ class Analysis_controller:
             print("debug> %s:  Deleting the analysis GUI object." % full_name)
         self._analyses.pop(index)
 
-        # Store the pipe bundle.
-        pipe_bundle = ds.relax_gui.analyses[index].pipe_bundle
+        # Data store clean up.
+        if not reset:
+            # Store the pipe bundle.
+            pipe_bundle = ds.relax_gui.analyses[index].pipe_bundle
 
-        # Delete the data store object.
-        if status.debug:
-            print("debug> %s:  Deleting the data store object." % full_name)
-        ds.relax_gui.analyses.pop(index)
+            # Delete the data store object.
+            if status.debug:
+                print("debug> %s:  Deleting the data store object." % full_name)
+            ds.relax_gui.analyses.pop(index)
 
-        # Delete all data pipes associated with the analysis.
-        for pipe in pipes.pipe_names():
-            if pipes.get_bundle(pipe) == pipe_bundle:
-                if status.debug:
-                    print("debug> %s:  Deleting the data pipe '%s' from the '%s' bundle." % (full_name, pipe, pipe_bundle))
-                pipes.delete(pipe)
+            # Delete all data pipes associated with the analysis.
+            for pipe in pipes.pipe_names():
+                if pipes.get_bundle(pipe) == pipe_bundle:
+                    if status.debug:
+                        print("debug> %s:  Deleting the data pipe '%s' from the '%s' bundle." % (full_name, pipe, pipe_bundle))
+                    pipes.delete(pipe)
 
         # No more analyses, so in the initial state.
         if self._num_analyses == 0:
@@ -418,11 +421,13 @@ class Analysis_controller:
         reset()
 
 
-    def menu_new(self, event):
+    def menu_new(self, event, destroy=True):
         """Launch a wizard to select the new analysis.
 
-        @param event:   The wx event.
-        @type event:    wx event
+        @param event:       The wx event.
+        @type event:        wx event
+        @keyword destroy:   A flag which if True will cause the analysis wizard to be destroyed.  This is used for the test suite.
+        @type destroy:      bool
         """
 
         # Execution lock.
@@ -433,6 +438,11 @@ class Analysis_controller:
         self.new_wizard = Analysis_wizard()
         data = self.new_wizard.run()
 
+        # Delete the wizard GUI element.
+        if destroy:
+            wx.Yield()
+            self.new_wizard.Destroy()
+
         # Failure, so do nothing.
         if data == None:
             return
@@ -443,9 +453,6 @@ class Analysis_controller:
         # Initialise the new analysis.
         self.new_analysis(analysis_type, analysis_name, pipe_name, pipe_bundle, uf_exec)
 
-        # Delete the wizard data.
-        del self.new_wizard
-
 
     def new_analysis(self, analysis_type=None, analysis_name=None, pipe_name=None, pipe_bundle=None, uf_exec=[], index=None):
         """Initialise a new analysis.
@@ -509,7 +516,7 @@ class Analysis_controller:
         }
 
         # Bad analysis type.
-        if analysis_type not in classes.keys():
+        if analysis_type not in classes:
             raise RelaxError("The analysis '%s' is unknown." % analysis_type)
 
         # Initialise the class.
@@ -687,38 +694,8 @@ class Analysis_controller:
     def post_reset(self):
         """Post relax data store reset event handler."""
 
-        # Debugging set up.
-        if status.debug:
-            fn_name = sys._getframe().f_code.co_name
-            mod_name = inspect.getmodule(inspect.stack()[1][0]).__name__
-            class_name = self.__class__.__name__
-            full_name = "%s.%s.%s" % (mod_name, class_name, fn_name)
-            print("\n\n")
-            print("debug> %s:  Deleting all analyses." % full_name)
-
-        # Unregister all observer objects prior to analysis deletion.  This is to prevent queued wx events being sent to dead or non-existent objects.
-        if status.debug:
-            print("debug> %s:  Unregistering all methods with the observer objects." % full_name)
-        for i in range(self._num_analyses):
-            self._analyses[i].observer_register(remove=True)
-
-        # Delete all tabs.
-        while self._num_analyses:
-            # The index of the tab to remove.
-            index = self._num_analyses - 1
-
-            # Delete the tab.
-            if hasattr(self, 'notebook'):
-                self.notebook.DeletePage(index)
-
-            # Delete the tab object.
-            self._analyses.pop(index)
-
-            # Decrement the number of analyses.
-            self._num_analyses -= 1
-
-        # Set the initial state.
-        self.set_init_state()
+        # Defer to the delete_all() method.
+        self.delete_all(reset=True)
 
 
     def set_init_state(self):
