@@ -106,7 +106,7 @@ def cone_angle_upper(incs=None, model_info=None):
     return pi * (1.0 - 1.0/(incs+1))
 
 
-def pivot_grid_bound(param=None, extent=10.0):
+def pivot_grid_bound(param=None, extent=25.0):
     """Determine the grid bounds for the pivot coordinates.
 
     @keyword param:     The parameter to find the bound for.  This should be one of 'pivot_x', 'pivot_y', or 'pivot_z'.
@@ -128,7 +128,7 @@ def pivot_grid_bound(param=None, extent=10.0):
     return val + extent
 
 
-def pivot_x_lower(incs=None, model_info=None, size=10.0):
+def pivot_x_lower(incs=None, model_info=None, size=25.0):
     """Determine the lower grid bound for the pivot X coordinate.
 
     @keyword incs:          The number of grid search increments.
@@ -145,7 +145,7 @@ def pivot_x_lower(incs=None, model_info=None, size=10.0):
     return pivot_grid_bound(param='pivot_x', extent=-size)
 
 
-def pivot_x_upper(incs=None, model_info=None, size=10.0):
+def pivot_x_upper(incs=None, model_info=None, size=25.0):
     """Determine the upper grid bound for the pivot X coordinate.
 
     @keyword incs:          The number of grid search increments.
@@ -162,7 +162,7 @@ def pivot_x_upper(incs=None, model_info=None, size=10.0):
     return pivot_grid_bound(param='pivot_x', extent=size)
 
 
-def pivot_y_lower(incs=None, model_info=None, size=10.0):
+def pivot_y_lower(incs=None, model_info=None, size=25.0):
     """Determine the lower grid bound for the pivot Y coordinate.
 
     @keyword incs:          The number of grid search increments.
@@ -179,7 +179,7 @@ def pivot_y_lower(incs=None, model_info=None, size=10.0):
     return pivot_grid_bound(param='pivot_y', extent=-size)
 
 
-def pivot_y_upper(incs=None, model_info=None, size=10.0):
+def pivot_y_upper(incs=None, model_info=None, size=25.0):
     """Determine the upper grid bound for the pivot Y coordinate.
 
     @keyword incs:          The number of grid search increments.
@@ -196,7 +196,7 @@ def pivot_y_upper(incs=None, model_info=None, size=10.0):
     return pivot_grid_bound(param='pivot_y', extent=size)
 
 
-def pivot_z_lower(incs=None, model_info=None, size=10.0):
+def pivot_z_lower(incs=None, model_info=None, size=25.0):
     """Determine the lower grid bound for the pivot Z coordinate.
 
     @keyword incs:          The number of grid search increments.
@@ -213,7 +213,7 @@ def pivot_z_lower(incs=None, model_info=None, size=10.0):
     return pivot_grid_bound(param='pivot_z', extent=-size)
 
 
-def pivot_z_upper(incs=None, model_info=None, size=10.0):
+def pivot_z_upper(incs=None, model_info=None, size=25.0):
     """Determine the upper grid bound for the pivot Z coordinate.
 
     @keyword incs:          The number of grid search increments.
@@ -260,7 +260,6 @@ class Frame_order_params(Param_list):
             desc = 'The pivot point position x coordinate',
             py_type = float,
             set = 'params',
-            scaling = 1e2,
             grid_lower = pivot_x_lower,
             grid_upper = pivot_x_upper,
             err = True,
@@ -273,7 +272,6 @@ class Frame_order_params(Param_list):
             desc = 'The pivot point position y coordinate',
             py_type = float,
             set = 'params',
-            scaling = 1e2,
             grid_lower = pivot_y_lower,
             grid_upper = pivot_y_upper,
             err = True,
@@ -286,12 +284,23 @@ class Frame_order_params(Param_list):
             desc = 'The pivot point position z coordinate',
             py_type = float,
             set = 'params',
-            scaling = 1e2,
             grid_lower = pivot_z_lower,
             grid_upper = pivot_z_upper,
             err = True,
             sim = True
         )
+        self._add(
+            'pivot_disp',
+            scope = 'global',
+            units = 'Angstrom',
+            desc = 'The 2nd pivot point displacement - the minimum distance between the two rotor axes',
+            py_type = float,
+            set = 'params',
+            grid_lower  =  10.0,
+            grid_upper  =  60.0,
+            err = True,
+            sim = True
+        )
         self._add(
             'ave_pos_x',
             scope = 'global',
@@ -299,8 +308,8 @@ class Frame_order_params(Param_list):
             desc = 'The average position x translation',
             py_type = float,
             set = 'params',
-            grid_lower = -5,
-            grid_upper = 5,
+            grid_lower = -50,
+            grid_upper = 50,
             err = True,
             sim = True
         )
@@ -311,8 +320,8 @@ class Frame_order_params(Param_list):
             desc = 'The average position y translation',
             py_type = float,
             set = 'params',
-            grid_lower = -5,
-            grid_upper = 5,
+            grid_lower = -50,
+            grid_upper = 50,
             err = True,
             sim = True
         )
@@ -323,8 +332,8 @@ class Frame_order_params(Param_list):
             desc = 'The average position z translation',
             py_type = float,
             set = 'params',
-            grid_lower = -5,
-            grid_upper = 5,
+            grid_lower = -50,
+            grid_upper = 50,
             err = True,
             sim = True
         )
@@ -472,18 +481,6 @@ class Frame_order_params(Param_list):
             err = True,
             sim = True
         )
-        self._add(
-            'cone_s1',
-            scope = 'global',
-            units = '',
-            desc = 'The isotropic cone order parameter',
-            py_type = float,
-            set = 'params',
-            grid_lower = -0.125,
-            grid_upper = 1.0,
-            err = True,
-            sim = True
-        )
         self._add(
             'cone_sigma_max',
             scope = 'global',
@@ -496,6 +493,18 @@ class Frame_order_params(Param_list):
             err = True,
             sim = True
         )
+        self._add(
+            'cone_sigma_max_2',
+            scope = 'global',
+            units = 'rad',
+            desc = 'The torsion angle of the 2nd motional mode',
+            py_type = float,
+            set = 'params',
+            grid_lower = cone_angle_lower,
+            grid_upper = cone_angle_upper,
+            err = True,
+            sim = True
+        )
 
         # Add minimisation structures.
         self._add_min_data(min_stats_global=True)
