@@ -1,6 +1,6 @@
 ###############################################################################
 #                                                                             #
-# Copyright (C) 2007-2014 Edward d'Auvergne                                   #
+# Copyright (C) 2007-2015 Edward d'Auvergne                                   #
 # Copyright (C) 2007 Gary S Thompson (https://gna.org/users/varioustoxins)    #
 #                                                                             #
 # This file is part of the program relax (http://www.nmr-relax.com).          #
@@ -119,7 +119,7 @@ class Model_free(API_base, API_common):
                     continue
 
                 # Check the unit vectors.
-                if not hasattr(interatoms[i], 'vector') or interatoms[i].vector == None:
+                if not hasattr(interatoms[i], 'vector') or interatoms[i].vector is None:
                     warn(RelaxDeselectWarning(spin_id, 'missing structural data'))
                     return
 
@@ -232,12 +232,17 @@ class Model_free(API_base, API_common):
         model_list = []
 
         # Store the spin specific data in lists for later use.
-        for spin, mol_name, res_num, res_name, spin_id in spin_loop(full_info=True, return_id=True):
+        for spin, mol_name, res_num, res_name, spin_id in spin_loop(full_info=True, skip_desel=True, return_id=True):
             # Skip the protons.
             if spin.name == 'H' or (hasattr(spin, 'element') and spin.element == 'H'):
                 warn(RelaxWarning("Skipping the proton spin '%s'." % spin_id))
                 continue
 
+            # No model setup.
+            if not hasattr(spin, 'model'):
+                warn(RelaxWarning("Skipping the spin '%s' as no model-free model has been set up." % spin_id))
+                continue
+
             # Check the data for None (not allowed in BMRB!).
             if res_num == None:
                 raise RelaxError("For the BMRB, the residue of spin '%s' must be numbered." % spin_id)
@@ -341,6 +346,10 @@ class Model_free(API_base, API_common):
             # Model-free model.
             model_list.append(to_bmrb_model(spin.model))
 
+        # Check that spin data is present.
+        if not len(model_list):
+            raise RelaxError("No model-free data could be found for any of the currently selected spins.")
+
         # Convert the molecule names into the entity IDs.
         entity_ids = zeros(len(mol_name_list), int32)
         mol_names = get_molecule_names()
@@ -1295,7 +1304,7 @@ class Model_free(API_base, API_common):
 
                 # Diagonal scaling.
                 data_store.scaling_matrix = scaling_matrix[index]
-                if data_store.scaling_matrix != None:
+                if data_store.scaling_matrix is not None:
                     opt_params.param_vector = dot(inv(data_store.scaling_matrix), opt_params.param_vector)
 
             # Store the grid search options.
@@ -1702,7 +1711,7 @@ class Model_free(API_base, API_common):
 
                 # Check the unit vectors.
                 if need_vect:
-                    if not hasattr(interatoms[i], 'vector') or interatoms[i].vector == None:
+                    if not hasattr(interatoms[i], 'vector') or interatoms[i].vector is None:
                         warn(RelaxDeselectWarning(spin_id, 'missing structural data'))
                         spin.select = False
                         deselect_flag = True
