@@ -23,16 +23,9 @@
 # Module docstring.
 """The R1 and R2 exponential relaxation curve fitting optimisation functions."""
 
-# Python module imports.
-from numpy import array, float64, ndarray, nan_to_num
-
 # relax module imports.
-from dep_check import C_module_exp_fn
 from specific_analyses.relax_fit.parameters import assemble_param_vector
-
-# C modules.
-if C_module_exp_fn:
-    from target_functions.relax_fit import setup, func, dfunc, d2func, back_calc_I
+from target_functions.relax_fit_wrapper import Relax_fit_opt
 
 
 def back_calc(spin=None, relax_time_id=None):
@@ -67,73 +60,13 @@ def back_calc(spin=None, relax_time_id=None):
         scaling_list.append(1.0)
 
     # Initialise the relaxation fit functions.
-    setup(num_params=len(spin.params), num_times=len(cdp.relax_times), values=values, sd=errors, relax_times=times, scaling_matrix=scaling_list)
+    model = Relax_fit_opt(model=spin.model, num_params=len(spin.params), values=values, errors=errors, relax_times=times, scaling_matrix=scaling_list)
 
     # Make a single function call.  This will cause back calculation and the data will be stored in the C module.
-    func_wrapper(param_vector)
+    model.func(param_vector)
 
     # Get the data back.
-    results = back_calc_I()
+    results = model.back_calc_data()
 
     # Return the correct peak height.
     return results[keys.index(relax_time_id)]
-
-
-def func_wrapper(params):
-    """Wrapper function for the C module, for converting numpy arrays.
-
-    @param params:  The parameter array from the minimisation code.
-    @type params:   numpy array
-    @return:        The function value generated by the C module.
-    @rtype:         float
-    """
-
-    # Convert if necessary.
-    if isinstance(params, ndarray):
-        params = params.tolist()
-
-    # Call the C code.
-    chi2 = func(params)
-
-    # Return the chi2 value.
-    return nan_to_num(chi2)
-
-
-def dfunc_wrapper(params):
-    """Wrapper function for the C module, for converting numpy arrays.
-
-    @param params:  The parameter array from the minimisation code.
-    @type params:   numpy array
-    @return:        The gradient generated by the C module converted to numpy format.
-    @rtype:         numpy float64 array
-    """
-
-    # Convert if necessary.
-    if isinstance(params, ndarray):
-        params = params.tolist()
-
-    # Call the C code.
-    dchi2 = dfunc(params)
-
-    # Return the chi2 gradient as a numpy array.
-    return array(dchi2, float64)
-
-
-def d2func_wrapper(params):
-    """Wrapper function for the C module, for converting numpy arrays.
-
-    @param params:  The parameter array from the minimisation code.
-    @type params:   numpy array
-    @return:        The Hessian generated by the C module converted to numpy format.
-    @rtype:         numpy float64 rank-2 array
-    """
-
-    # Convert if necessary.
-    if isinstance(params, ndarray):
-        params = params.tolist()
-
-    # Call the C code.
-    d2chi2 = d2func(params)
-
-    # Return the chi2 Hessian as a numpy array.
-    return array(d2chi2, float64)
