@@ -2,7 +2,8 @@
 from os import sep
 
 # relax imports.
-from lib.physical_constants import NH_BOND_LENGTH_RDC, dipolar_constant, g15N, g1H
+from lib.periodic_table import periodic_table
+from lib.physical_constants import NH_BOND_LENGTH_RDC, dipolar_constant
 from status import Status; status = Status()
 
 
@@ -19,7 +20,7 @@ self._execute_uf(uf_name='structure.read_pdb', file='trunc_ubi_pcs.pdb', dir=str
 self._execute_uf(uf_name='structure.load_spins', spin_id='@H')
 
 # The dipolar constant.
-const = 3.0 / (2.0*pi) * dipolar_constant(g15N, g1H, NH_BOND_LENGTH_RDC)
+const = 3.0 / (2.0*pi) * dipolar_constant(periodic_table.gyromagnetic_ratio('15N'), periodic_table.gyromagnetic_ratio('1H'), NH_BOND_LENGTH_RDC)
 
 # The tensor.
 tensor = 'A'
